@@ -41,6 +41,7 @@
 #include "user-settings.h"
 #include "user_group.h"
 #include "passwd.h"
+#include "privileges-table.h"
 
 #define MAX_TOKENS 8
 
@@ -48,39 +49,6 @@ extern GstTool *tool;
 extern GList *groups_list;
 xmlNodePtr user_profile;
 
-static void
-create_groups_gtk_trees (void)
-{
-	GtkWidget *user_settings_all = gst_dialog_get_widget (tool->main_dialog, "user_settings_all");
-	GtkWidget *user_settings_members = gst_dialog_get_widget (tool->main_dialog, "user_settings_members");
-	GtkWidget *add_button, *remove_button;
-	GtkTreeSelection *selection;
-	GtkSizeGroup *sizegroup = gtk_size_group_new (GTK_SIZE_GROUP_BOTH);
-	GtkTargetEntry target = { "group", GTK_TARGET_SAME_APP, 0 };
-	
-	/* connect signals and attach data if they haven't been created already */
-	if (g_object_get_data (G_OBJECT (user_settings_all), "button") == NULL) {
-		create_gtk_tree_list (user_settings_all, target);
-		g_object_set_data (G_OBJECT (user_settings_all), "button", "user_settings_add");
-
-		create_gtk_tree_list (user_settings_members, target);
-		g_object_set_data (G_OBJECT (user_settings_members), "button", "user_settings_remove");
-
-		/* We also need to attach some data to the 'add' and 'remove' buttons */
-		add_button = gst_dialog_get_widget (tool->main_dialog, "user_settings_add");
-		g_object_set_data (G_OBJECT (add_button), "in", user_settings_all);
-		g_object_set_data (G_OBJECT (add_button), "out", user_settings_members);
-		
-		remove_button = gst_dialog_get_widget (tool->main_dialog, "user_settings_remove");
-		g_object_set_data (G_OBJECT (remove_button), "in", user_settings_members);
-		g_object_set_data (G_OBJECT (remove_button), "out", user_settings_all);
-
-		/* Add the scrolled windows that contain the trees in the same GtkSizeGroup */
-		gtk_size_group_add_widget (sizegroup, gst_dialog_get_widget (tool->main_dialog, "group_settings_all_container"));
-		gtk_size_group_add_widget (sizegroup, gst_dialog_get_widget (tool->main_dialog, "group_settings_members_container"));
-	}
-}
-
 static gboolean
 check_user_delete (xmlNodePtr node)
 {
@@ -101,7 +69,7 @@ check_user_delete (xmlNodePtr node)
 
 	if (strcmp (login, "root") == 0) {
 		show_error_message ("user_settings_dialog",
-				    _("The root user can not be deleted."),
+				    _("The \"root\" user should not be deleted"),
 				    _("This would leave the system unusable"));
 		g_free (login);
 		return FALSE;
@@ -112,12 +80,12 @@ check_user_delete (xmlNodePtr node)
 				     GST_HIG_MESSAGE_WARNING,
 				     NULL,
 				     "This will disable the access of this user to the system, "
-				     "but the user's home directory wont be deleted",
+				     "but his home directory will not be deleted",
 				     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 				     GTK_STOCK_DELETE, GTK_RESPONSE_ACCEPT,
 				     NULL);
 	gst_hig_dialog_set_primary_text (GST_HIG_DIALOG (dialog),
-					 _("Are you sure you want to delete user %s?"), login);
+					 _("Are you sure you want to delete user \"%s\"?"), login);
 
 	reply = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
@@ -151,6 +119,8 @@ user_set_profile (xmlNodePtr profile)
 	gchar *buf;
 	ug_data *ud;
 	GtkWidget *widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
+
+	g_return_if_fail (profile != NULL);
 	
 	ud = g_object_get_data (G_OBJECT (widget), "data");
 
@@ -159,39 +129,41 @@ user_set_profile (xmlNodePtr profile)
 	g_free (buf);
 
 	buf = gst_xml_get_child_content (profile, "shell");
-	gtk_entry_set_text (GTK_ENTRY (gst_dialog_get_widget (tool->main_dialog, "user_settings_shell_entry")), buf);
+	gtk_entry_set_text (GTK_ENTRY (GTK_BIN (gst_dialog_get_widget (tool->main_dialog, "user_settings_shell"))->child), buf);
 	g_free (buf);
 
-	/* There are OS (like FreeBSD) that don't have these parameters, hide them if the tags don't exist*/
+	/* FIXME: this is hidden, will this section be ever necessary? */
+	gtk_widget_hide (gst_dialog_get_widget (tool->main_dialog, "user_optional_settings"));
+
+/*
 	buf = gst_xml_get_child_content (profile, "pwd_maxdays");
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_passwd_max")),
+				   g_strtod (buf, NULL));
+	g_free (buf);
 
-	if (!buf)
-		gtk_widget_hide (gst_dialog_get_widget (tool->main_dialog, "user_optional_settings"));
-	else {
-		gtk_spin_button_set_value (GTK_SPIN_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_passwd_max")),
-					   g_strtod (buf, NULL));
-		g_free (buf);
+	buf = gst_xml_get_child_content (profile, "pwd_mindays");
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_passwd_min")),
+				   g_strtod (buf, NULL));
+	g_free (buf);
 
-		buf = gst_xml_get_child_content (profile, "pwd_mindays");
-		gtk_spin_button_set_value (GTK_SPIN_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_passwd_min")),
-					   g_strtod (buf, NULL));
-		g_free (buf);
+	buf = gst_xml_get_child_content (profile, "pwd_warndays");
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_passwd_days")),
+				   g_strtod (buf, NULL));
+	g_free (buf);
+*/
 
-		buf = gst_xml_get_child_content (profile, "pwd_warndays");
-		gtk_spin_button_set_value (GTK_SPIN_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_passwd_days")),
-					   g_strtod (buf, NULL));
-		g_free (buf);
-	}
+	populate_privileges_table_from_profile (profile);
 
 	value = gst_xml_get_child_content (profile, "group");
 	element = g_list_first (groups_list);
 
-	while ((element != NULL) && (strcmp (element->data, value) != 0))
-	{
+	while ((element != NULL) && (strcmp (element->data, value) != 0)) {
 		element = element->next;
 		counter++;
 	}
-	gtk_option_menu_set_history (GTK_OPTION_MENU (gst_dialog_get_widget (tool->main_dialog, "user_settings_group")), counter);
+
+	gtk_combo_box_set_active (GTK_COMBO_BOX (gst_dialog_get_widget (tool->main_dialog, "user_settings_group")),
+				  counter);
 
 	/* Gets a new uid */
 	buf = (gchar *) find_new_id (ud->node, profile);
@@ -207,27 +179,21 @@ user_set_profile (xmlNodePtr profile)
 void
 user_new_prepare (ug_data *ud)
 {
-	GtkWidget *button;
+	GtkWidget *button, *list;
 	gchar *buf;
-	GList *user_settings_all_list = NULL;
 	GtkWidget *widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
-	GtkWidget *user_settings_all = gst_dialog_get_widget (tool->main_dialog, "user_settings_all");
-	GtkWidget *user_settings_members = gst_dialog_get_widget (tool->main_dialog, "user_settings_members");
 
 	gtk_window_set_title (GTK_WINDOW (widget), _("User Account Editor"));
 	g_object_set_data (G_OBJECT (widget), "data", ud);
 
 	gtk_widget_show (gst_dialog_get_widget (tool->main_dialog, "user_settings_profiles"));
-	
-	/* Creates and fills GtkTrees */
-	create_groups_gtk_trees ();
-	user_settings_all_list = get_list_from_node ("name", NODE_GROUP);
-	populate_gtk_tree_list (GTK_TREE_VIEW (user_settings_all), user_settings_all_list);
-	
+
+	list = gst_dialog_get_widget (tool->main_dialog, "user_privileges");
+
 	/* Fill menus */
-	option_menu_add_groups (gst_dialog_get_widget (tool->main_dialog, "user_settings_group"), TRUE);
-	combo_add_shells (gst_dialog_get_widget (tool->main_dialog, "user_settings_shell"));
-	option_menu_add_profiles (gst_dialog_get_widget (tool->main_dialog, "user_settings_profile_menu"));
+	combo_add_groups   (gst_dialog_get_widget (tool->main_dialog, "user_settings_group"), TRUE);
+	combo_add_shells   (gst_dialog_get_widget (tool->main_dialog, "user_settings_shell"));
+	combo_add_profiles (gst_dialog_get_widget (tool->main_dialog, "user_settings_profile_menu"));
 
 #ifdef HAVE_LIBCRACK
 	/* If we have libcrack, password quality check is enabled */
@@ -242,8 +208,6 @@ user_new_prepare (ug_data *ud)
 void
 user_settings_dialog_close (void)
 {
-	GtkWidget *user_settings_all = gst_dialog_get_widget (tool->main_dialog, "user_settings_all");
-	GtkWidget *user_settings_members = gst_dialog_get_widget (tool->main_dialog, "user_settings_members");
 	GtkWidget *widget;
 	GtkTreeModel *model;
 	ug_data *ud;
@@ -267,19 +231,6 @@ user_settings_dialog_close (void)
 		gtk_entry_set_text (GTK_ENTRY (widget), "");
 	}
 
-	/* Clear both lists */
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (user_settings_all));
-	gtk_tree_store_clear (GTK_TREE_STORE (model));
-
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (user_settings_members));
-	gtk_tree_store_clear (GTK_TREE_STORE (model));
-	
-	/* Set unsensitive the add and remove buttons */
-	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_add");
-	gtk_widget_set_sensitive (widget, FALSE);
-	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_remove");
-	gtk_widget_set_sensitive (widget, FALSE);
-	
 	/* Set the manual password */
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_passwd_manual");
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
@@ -296,7 +247,8 @@ user_settings_dialog_close (void)
 	gtk_widget_hide (widget);
 
 	/* Clear groups option menu */
-	gtk_option_menu_remove_menu (GTK_OPTION_MENU (gst_dialog_get_widget (tool->main_dialog, "user_settings_group")));
+	model = gtk_combo_box_get_model (GTK_COMBO_BOX (gst_dialog_get_widget (tool->main_dialog, "user_settings_group")));
+	gtk_list_store_clear (GTK_LIST_STORE (model));
 }
 
 static gboolean
@@ -329,39 +281,40 @@ is_login_valid (xmlNodePtr node, const gchar *login)
 
 	/* If !empty. */
 	if (strlen (login) < 1) {
-		primary_text = g_strdup (_("The username is empty."));
-		secondary_text = g_strdup (_("A username must be specified"));
+		primary_text = g_strdup (_("The user name is empty"));
+		secondary_text = g_strdup (_("A user name must be specified"));
 	}
 
 	/* If too long. */
 #ifdef __FreeBSD__
 	else if (strlen (login) > UT_NAMESIZE) { /*  = sizeof (ut.ut_name) */
-		primary_text   = g_strdup (_("The username is too long."));
-		secondary_text = g_strdup_printf (_("The username should have less than %i characters for being valid"), UT_NAMESIZE);
+		primary_text   = g_strdup (_("The user name is too long"));
+		secondary_text = g_strdup_printf (_("The user name should have less than %i characters for being valid"), UT_NAMESIZE);
 	}
 #else
 	else if (strlen (login) > sizeof (ut.ut_user)) {
-		primary_text   = g_strdup (_("The username is too long."));
-		secondary_text = g_strdup_printf (_("The username should have less than %i characters for being valid"), sizeof (ut.ut_user));
+		primary_text   = g_strdup (_("The user name is too long"));
+		secondary_text = g_strdup_printf (_("The user name should have less than %i characters for being valid"), sizeof (ut.ut_user));
 	}
 #endif
 
 	/* If user being modified is root */
 	else if ((is_user_root (node)) && (strcmp (login, "root") != 0)) {
-		primary_text   = g_strdup (_("Root username shouldn't be modified."));
+		primary_text   = g_strdup (_("User name for the \"root\" user should not be modified"));
 	        secondary_text = g_strdup (_("This would leave the system unusable"));
 	}
 
 	/* if valid. */
 	else if (!is_valid_name (login)) {
-		primary_text   = g_strdup (_("Username has invalid characters"));
-		secondary_text = g_strdup (_("Please set a valid username consisting of a lower case letter followed by lower case letters and numbers."));
+		primary_text   = g_strdup (_("User name has invalid characters"));
+		secondary_text = g_strdup (_("Please set a valid user name consisting of "
+					     "a lower case letter followed by lower case letters and numbers"));
 	}
 
 	/* if !exist. */
 	else if (node_exists (node, "login", login)) {
-		primary_text   = g_strdup_printf (_("Username \"%s\" already exists"), login);
-		secondary_text = g_strdup (_("Please select a different username"));
+		primary_text   = g_strdup_printf (_("User name \"%s\" already exists"), login);
+		secondary_text = g_strdup (_("Please select a different user name"));
 	}
 
 	/* If anything is wrong. */
@@ -386,8 +339,8 @@ is_comment_valid (gchar *name, gchar *location, gchar *wphone, gchar *hphone)
 	
 	for (i = 0; i < strlen (comment); i++) {
 		if (iscntrl (comment[i]) || comment[i] == ',' || comment[i] == '=' || comment[i] == ':') {
-			primary_text   = g_strdup_printf (N_("Invalid character in comment."));
-			secondary_text = g_strdup_printf (N_("Check that invalid character '%c' is not used"), comment[i]);
+			primary_text   = g_strdup_printf (N_("Invalid character \"%c\" in comment"), comment[i]);
+			secondary_text = g_strdup (N_("Check that this character is not used"));
 			break;
 		}
 	}
@@ -435,24 +388,24 @@ is_home_valid (xmlNodePtr node, gchar *home)
 	struct stat s;
 	
 	if (!home || (strlen (home) < 1)) {
-		primary_text   = g_strdup (N_("Home directory must not be empty."));
+		primary_text   = g_strdup (N_("Home directory should not be empty"));
 		secondary_text = g_strdup (N_("Make sure you provide a home directory"));
 	} else if (*home != '/') {
 		primary_text   = g_strdup (N_("Incomplete path in home directory"));
-		secondary_text = g_strdup (N_("Please enter full path for home directory.\n"
+		secondary_text = g_strdup (N_("Please enter full path for home directory\n"
 					      "<span size=\"smaller\">i.e.: /home/john</span>"));
 	} else if ((is_user_root (node)) && (strcmp (home, "/root") != 0)) {
-		primary_text   = g_strdup (N_("root home shouldn't be modified."));
+		primary_text   = g_strdup (N_("Home directory of the \"root\" user should not be modified"));
 		secondary_text = g_strdup (N_("This would leave the system unusable"));
 	}
 
 /*	else if (stat (home, &s))
 	{
 		switch (errno) {
-		case ENOTDIR: buf = g_strdup (_("Part of the path to the home directory is a file."));
-		case ELOOP:   buf = g_strdup (_("There is a loop in the path to the home directory."));
-		case ENOMEM:  buf = g_strdup (_("Not enough memory to check the home directory."));
-		case ENAMETOOLONG: buf = g_strdup (_("The path to the home directory is too long."));
+		case ENOTDIR: buf = g_strdup (_("Part of the path to the home directory is a file"));
+		case ELOOP:   buf = g_strdup (_("There is a loop in the path to the home directory"));
+		case ENOMEM:  buf = g_strdup (_("Not enough memory to check the home directory"));
+		case ENAMETOOLONG: buf = g_strdup (_("The path to the home directory is too long"));
 		}
 	}
 */
@@ -476,9 +429,9 @@ is_user_uid_valid (xmlNodePtr node, const gchar *uid)
 
 	if (!is_valid_id (uid)) {
 		primary_text   = g_strdup (N_("Invalid user ID"));
-		secondary_text = g_strdup (N_("User id must be a positive number."));
+		secondary_text = g_strdup (N_("User ID must be a positive number"));
 	} else if ((is_user_root (node)) && (strcmp (uid, "0") != 0)) {
-		primary_text   = g_strdup (N_("root user ID should not be modified"));
+		primary_text   = g_strdup (N_("User ID of the \"root\" user should not be modified"));
 		secondary_text = g_strdup (N_("This would leave the system unusable"));
 	}
 	
@@ -518,7 +471,7 @@ is_shell_valid (const gchar *val)
 	
 	if (strlen (val) > 0 && *val != '/') {
 		primary_text   = g_strdup (N_("Incomplete path in shell"));
-		secondary_text = g_strdup (N_("Please enter full path for shell.\n"
+		secondary_text = g_strdup (N_("Please enter full path for shell\n"
 					      "<span size=\"smaller\">i.e.: /bin/sh</span>"));
 	}
 
@@ -540,10 +493,10 @@ is_password_valid (const gchar *passwd1, const gchar *passwd2)
 	gchar *secondary_text = NULL;
 	
 	if (!passwd1 || !passwd2 || strlen (passwd1) < 1 || strlen (passwd2) < 1) {
-		primary_text   = g_strdup (N_("Password can not be empty."));
+		primary_text   = g_strdup (N_("Password should not be empty"));
 		secondary_text = g_strdup (N_("A password must be provided"));
 	} else if (strcmp (passwd1, passwd2) != 0) {
-		primary_text   = g_strdup (N_("Password confirmation isn't correct."));
+		primary_text   = g_strdup (N_("Password confirmation isn't correct"));
 		secondary_text = g_strdup (N_("Check that you have provided the same password in both text fields"));
 	}
 
@@ -578,7 +531,6 @@ group_check (xmlNodePtr node, const gchar *groupname)
 gboolean
 user_update (ug_data *ud)
 {
-	GtkWidget *user_settings_members = gst_dialog_get_widget (tool->main_dialog, "user_settings_members");
 	UserAccountData *data;
 	gboolean change_password = FALSE;
 	GList *list;
@@ -618,7 +570,7 @@ user_update (ug_data *ud)
 	}
 	
 	/* check user shell */
-	data->shell = (gchar *) gtk_entry_get_text (GTK_ENTRY (gst_dialog_get_widget (tool->main_dialog, "user_settings_shell_entry")));
+	data->shell = (gchar *) gtk_entry_get_text (GTK_ENTRY (GTK_BIN (gst_dialog_get_widget (tool->main_dialog, "user_settings_shell"))->child));
 	if (!is_shell_valid (data->shell)) {
 		return FALSE;
 	}
@@ -653,17 +605,17 @@ user_update (ug_data *ud)
 	}
 
 	/* get user main group GID*/
-	data->group = g_list_nth_data (groups_list, gtk_option_menu_get_history (GTK_OPTION_MENU (gst_dialog_get_widget (tool->main_dialog, "user_settings_group"))));
+	data->group = g_list_nth_data (groups_list, gtk_combo_box_get_active (GTK_COMBO_BOX (gst_dialog_get_widget (tool->main_dialog, "user_settings_group"))));
 	if (strcmp (data->group, "$user") == 0)
 		data->group = data->login;
 	
 	data->gid = group_check (ud->node, data->group);
-	if (!data->gid) {
+	if (!data->gid)
 		return FALSE;
-	}
 
-	g_list_free (data->extra_groups);
-	data->extra_groups = get_gtk_tree_list_items (GTK_TREE_VIEW (user_settings_members));
+	data->extra_groups = NULL;
+	data->extra_groups = user_get_groups (ud->node);
+	data->extra_groups = user_privileges_get_list (data->extra_groups);
 
 	data->pwd_maxdays = g_strdup_printf ("%i", gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_passwd_max"))));
 	data->pwd_mindays = g_strdup_printf ("%i", gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_passwd_min"))));
@@ -727,14 +679,10 @@ user_settings_dialog_prepare_comments (gchar *comments)
 static void
 user_settings_dialog_prepare (ug_data *ud)
 {
-	GtkWidget *user_settings_all = gst_dialog_get_widget (tool->main_dialog, "user_settings_all");
-	GtkWidget *user_settings_members = gst_dialog_get_widget (tool->main_dialog, "user_settings_members");
 	GtkWidget *option_menu = gst_dialog_get_widget (tool->main_dialog, "user_settings_group");
 	GtkWidget *combo = gst_dialog_get_widget (tool->main_dialog, "user_settings_shell");
 	GtkWidget *w0;
 	gchar *txt, *name;
-	GList *user_settings_all_list = NULL;
-	GList *user_settings_members_list = NULL;
 	gint counter = 0;
 	GList *element;
 	
@@ -769,61 +717,50 @@ user_settings_dialog_prepare (ug_data *ud)
 	/* Set shells combo */
 	combo_add_shells (combo);
 	txt = gst_xml_get_child_content (ud->node, "shell");
-	w0 = gst_dialog_get_widget (tool->main_dialog, "user_settings_shell_entry");
-	gst_ui_entry_set_text (w0, txt);
+	w0 = gst_dialog_get_widget (tool->main_dialog, "user_settings_shell");
+	gtk_entry_set_text (GTK_ENTRY (GTK_BIN (w0)->child), txt);
 	g_free (txt);
 	
 	/* set main group option menu */
-	option_menu_add_groups (option_menu, FALSE);
+	combo_add_groups (option_menu, FALSE);
 	txt = get_group_name (gst_xml_get_child_content (ud->node, "gid"));
 
 	if (txt != NULL) {
 		element = g_list_first (groups_list);
 
-		while ((element != NULL) && (strcmp (element->data, txt) != 0))
-		{
+		while ((element != NULL) && (strcmp (element->data, txt) != 0))	{
 			element = element->next;
 			counter++;
 		}
-		gtk_option_menu_set_history (GTK_OPTION_MENU (gst_dialog_get_widget (tool->main_dialog, "user_settings_group")), counter);
+		gtk_combo_box_set_active (GTK_COMBO_BOX (gst_dialog_get_widget (tool->main_dialog, "user_settings_group")), counter);
 		g_free (txt);
 	}
-	
-	/* Fill groups lists */
-	create_groups_gtk_trees ();
 
-	user_settings_members_list = user_get_groups (ud->node);
-	user_settings_all_list = my_g_list_remove_duplicates (get_list_from_node ("name", NODE_GROUP), user_settings_members_list);
-	populate_gtk_tree_list (GTK_TREE_VIEW (user_settings_all), user_settings_all_list);
-	populate_gtk_tree_list (GTK_TREE_VIEW (user_settings_members), user_settings_members_list);
+	w0 = gst_dialog_get_widget (tool->main_dialog, "user_privileges");
+	populate_privileges_table (w0, name);
 	
 	/* Set password */
 	user_settings_dialog_prepare_password ();
 
-	/* these values don't exist in some OS (say FreeBSD) so we hide them */
-	txt = gst_xml_get_child_content (ud->node, "passwd_max_life");
+	/* FIXME: This is hidden, will this section be ever necessary? */
+	w0 = gst_dialog_get_widget (tool->main_dialog, "user_optional_settings");
+	gtk_widget_hide (w0);
 
-	if (!txt) {
-		w0 = gst_dialog_get_widget (tool->main_dialog, "user_optional_settings");
-		gtk_widget_hide (w0);
-	} else {
-		/* Set maxdays */
-		w0 = gst_dialog_get_widget (tool->main_dialog, "user_passwd_max");
-		gtk_spin_button_set_value (GTK_SPIN_BUTTON (w0), g_strtod (txt, NULL));
-		g_free (txt);
+/*
+	w0 = gst_dialog_get_widget (tool->main_dialog, "user_passwd_max");
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w0), g_strtod (txt, NULL));
+	g_free (txt);
 	
-		/* Set mindays */
-		txt = gst_xml_get_child_content (ud->node, "passwd_min_life");
-		w0 = gst_dialog_get_widget (tool->main_dialog, "user_passwd_min");
-		gtk_spin_button_set_value (GTK_SPIN_BUTTON (w0), g_strtod (txt, NULL));
-		g_free (txt);
+	txt = gst_xml_get_child_content (ud->node, "passwd_min_life");
+	w0 = gst_dialog_get_widget (tool->main_dialog, "user_passwd_min");
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w0), g_strtod (txt, NULL));
+	g_free (txt);
 	
-		/* Set warndays */
-		txt = gst_xml_get_child_content (ud->node, "passwd_exp_warn");
-		w0 = gst_dialog_get_widget (tool->main_dialog, "user_passwd_days");
-		gtk_spin_button_set_value (GTK_SPIN_BUTTON (w0), g_strtod (txt, NULL));
-		g_free (txt);
-	}
+	txt = gst_xml_get_child_content (ud->node, "passwd_exp_warn");
+	w0 = gst_dialog_get_widget (tool->main_dialog, "user_passwd_days");
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w0), g_strtod (txt, NULL));
+	g_free (txt);
+*/
 	
 	/* Set window title */
 	w0 = gst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
